# ===================================================================================
#
# SharePoint Products - CopyMove Upgrade
#
# ===================================================================================

$Host.UI.RawUI.WindowTitle = "Upgrading CopyMove 2010"
$0 = $myInvocation.MyCommand.Definition
$dp0 = [System.IO.Path]::GetDirectoryName($0)
. "$dp0\Functions.ps1"

$myWindowsID=[System.Security.Principal.WindowsIdentity]::GetCurrent()
$myWindowsPrincipal=new-object System.Security.Principal.WindowsPrincipal($myWindowsID)
$adminRole=[System.Security.Principal.WindowsBuiltInRole]::Administrator
if ($myWindowsPrincipal.IsInRole($adminRole))
{
	$Host.UI.RawUI.BackgroundColor = "DarkBlue"
	clear-host
} else
{
	$newProcess = new-object System.Diagnostics.ProcessStartInfo "PowerShell";
	$newProcess.Arguments = $myInvocation.MyCommand.Definition;
    $newProcess.Verb = "runas";
    [System.Diagnostics.Process]::Start($newProcess);
    exit
}

Load-SharePoint-Powershell

EnsureEventSource "SharePoint Products"

Write-Host "- Restarting IIS"
Restart-Service W3SVC -force

Write-Host "- Restarting Timer Service"
Restart-Service SPTimerV4

Write-Host "- Retracting Solutions"
UninstallFarmSolution("sharepointproducts_copymove.wsp")
UninstallFarmSolution("sharepointproducts_platform.wsp")

Write-Host "- Removing Solutions"
RemoveFarmSolution("sharepointproducts_copymove.wsp")
RemoveFarmSolution("sharepointproducts_platform.wsp")

Write-Host "- Restarting Timer Service"
Restart-Service SPTimerV4

Write-Host "- Adding solutions"
AddFarmSolution("$dp0\..\WSP\sharepointproducts_platform.wsp")
AddFarmSolution("$dp0\..\WSP\sharepointproducts_copymove.wsp")

Write-Host "- Deploying solutions"
InstallFarmSolution("sharepointproducts_platform.wsp")
InstallFarmSolution("sharepointproducts_copymove.wsp")

Write-Host "- Enabling CopyMove farm feature"
Enable-SPFeature -Identity SPPCopyMoveFarm

Write-Host "- Restarting Timer Service"
Restart-Service SPTimerV4

Write-Host ""
Write-Host "- Upgrade complete - configure CopyMove as follows:"
Write-Host "- 1. Navigate to 'Central Administation -> Manage farm features'"
Write-Host "- 2. Ensure that the feature 'SharePoint Products - CopyMove for SharePoint 2010' is activated"
Write-Host "- 3. Activate the CopyMove site collection feature feature on all applicable site collections"
Write-Host "- 4. Optionally change default settings from 'Central Administration -> CopyMove settings'"
Write-Host "- 5. Done"
Write-Host ""

Pause

